pub enum OperationError {
KeyExpansionFailed(KeyExpansionError),
EmptyTarget,
InvalidTargetSize,
}Expand description
An error produced during an encryption/decryption.
Variants
KeyExpansionFailed(KeyExpansionError)
The key expansion failed.
EmptyTarget
The provided target had no data.
InvalidTargetSize
The given target’s data is less than the block size for AES, and thus cannot be fed to the encryption/decryption algorithm.
For decryption, the target’s data is most likely not a result of an AES encryption.
For encryption, consider applying pkcs5_padding to the target’s data before using encrypt.