pub struct ExpandedKey { /* private fields */ }Expand description
A set of generated keys to account for each round of the said cipher version encryption/decryption process.
Implementations
Sourceimpl ExpandedKey
impl ExpandedKey
Sourcepub fn new(
cipher_version: &CipherVersion<'_>,
) -> Result<ExpandedKey, KeyExpansionError>
pub fn new( cipher_version: &CipherVersion<'_>, ) -> Result<ExpandedKey, KeyExpansionError>
Expands the given key based on the specified cipher version.